@@ -419,7 +419,7 @@ def printNodeTree(
         depthSpace += f'{c.TAB_UNITS * c.SPACE}'
     depth += 1
     for node in list(tree) :
-        if ObjectHelper.isDictionary(tree[node]) and ObjectHelper.isNotEmptyCollection(tree[node]) :
+        if ObjectHelper.isDictionary(tree[node]) :
             print(f'{depthSpace}{settingKeyColor}{node}{colonColor}{c.SPACE}{c.COLON}')
             printNodeTree(
                 tree[node],
